@@ -19,20 +19,13 @@ my $dbh = DBI->connect()
 my %InfoTests = (
 		 'SQL_DRIVER_NAME', 6,
 		 'SQL_DRIVER_VER', 7,
-		 'SQL_DRIVER_ODBC_VER', 77,
-		 'SQL_DATABASE_NAME', 16,
-		 'SQL_DBMS_NAME', 17,
-		 'SQL_DBMS_VER', 18,
-		 'SQL_DM_VER', 171,
-		 'SQL_IDENTIFIER_QUOTE_CHAR', 29,
-		 'SQL_CATALOG_NAME_SEPARATOR', 41,
-		 'SQL_CATALOG_LOCATION', 114,
 		 'SQL_CURSOR_COMMIT_BEHAVIOR', 23,
 		 'SQL_ALTER_TABLE', 86,
 		 'SQL_ACCESSIBLE_PROCEDURES', 20,
 		 'SQL_PROCEDURES', 21,
 		 'SQL_MULT_RESULT_SETS', 36,
 		 'SQL_PROCEDURE_TERM', 40,
+		 'SQL_DATABASE_NAME', 16,
 		);
 
 my %TypeTests = (
@@ -50,12 +43,11 @@ print "\nInformation for DBI_DSN=$ENV{'DBI_DSN'}\n\n";
 my $SQLInfo;
 foreach $SQLInfo (sort keys %InfoTests) {
    $ret = 0;
-   $ret = $dbh->get_info($InfoTests{$SQLInfo});
+   $ret = $dbh->func($InfoTests{$SQLInfo}, GetInfo);
    print "$SQLInfo ($InfoTests{$SQLInfo}):\t$ret\n";
 }
 
-print "\nGetfunctions   : ", join(",", $dbh->func(0, GetFunctions)), "\n\n";
-print "\nGetfunctions v3: ", join(",", $dbh->func(999, GetFunctions)), "\n\n";
+print "\nGetfunctions: ", join(",", $dbh->func(0, GetFunctions)), "\n\n";
 
 foreach $SQLInfo (sort keys %TypeTests) {
    print "Listing all $SQLInfo types\n";
@@ -76,16 +68,15 @@ foreach $SQLInfo (sort keys %TypeTests) {
 	 push(@coldescs, $sname);
 	 # print "Desc Col: ", join(', ', &nullif($sth->func($i, DescribeCol))), "\n";
       }	
-      # print join(', ', @coldescs), "\n";
+      print join(', ', @coldescs), "\n";
       while (@row = $sth->fetchrow()) {
-	 
-	 print "$row[0]\n\t",
+	 # print "$row[0]\n\t",
 	 # &nullif($row[1]), ", " ,
-	 #&nullif($row[2]), ", " ,
-	 #&nullif($row[3]), ", " ,
-	 #&nullif($row[4]), ", " ,
-	 #&nullif($row[5]), "\n";
-	 # print join(', ', @row), "\n";
+	 # &nullif($row[2]), ", " ,
+	 # &nullif($row[3]), ", " ,
+	 # &nullif($row[4]), ", " ,
+	 # &nullif($row[5]), "\n";
+	 print join(', ', @row), "\n";
       }
       $sth->finish();
    } else {
@@ -94,8 +85,6 @@ foreach $SQLInfo (sort keys %TypeTests) {
    }
 }	
 
-my $SQL_XOPEN_CLI_YEAR = 10000;
-print $dbh->get_info($SQL_XOPEN_CLI_YEAR), "\n";
 $dbh->disconnect();
 
 sub nullif ($) {
